@@ -15,7 +15,7 @@ from invoke import Collection  # noqa, re-export
 from fh_fablib.extract_js_gettext_strings import generate_strings
 
 
-__version__ = "1.0.20211124"
+__version__ = "1.0.20220315"
 
 
 # I don't care, in this context.
@@ -23,7 +23,7 @@ warnings.simplefilter("ignore", category=ResourceWarning)
 
 
 def ansi(code):
-    return lambda s: "\033[{}m{}\033[0m".format(code, s)
+    return lambda s: f"\033[{code}m{s}\033[0m"
 
 
 # underline = ansi("4")
@@ -88,8 +88,6 @@ class Config:
 
         os.chdir(self.base)
 
-        # TODO: check/add hook on every config initialization
-
     def __getattr__(self, key):
         environments = getattr(self, "environments", None)
         if environments:
@@ -163,25 +161,18 @@ for job in $(jobs -p); do wait $job; done
         run(ctx, f"bash {f.name}", replace_env=False)
 
 
-@task
-def hook(ctx):
+@task(auto_shortflags=False, help={"force": "Overwrite existing pre-commit files"})
+def hook(ctx, force=False):
     """
     Add default pre-commit configuration and install hook running coding style checks
     """
-    # shutil.copy(
-    #     Path(__file__).parent / "pre-commit-defaults.yaml",
-    #     config.base / ".pre-commit-config.yaml"
-    # )
-
-    defaults = Path(__file__).parent / "pre-commit-defaults.yaml"
-    pre_commit_config = config.base / ".pre-commit-config.yaml"
-    pre_commit_config.write_text(
-        defaults.read_text().replace(
-            "###FRONTEND_STATIC_PATTERN###",
-            f"{config.app}/static/.*$"
-        )
-    )
-
+    source = Path(__file__).parent / "dotfiles"
+    target = config.base
+    for s in source.glob(".*"):
+        t = target / s.name
+        if force or not t.exists():
+            shutil.copy(s, t)
+            info(f"Copying {s.name} into project...")
     run(ctx, "pre-commit install -f")
 
 
@@ -204,6 +195,8 @@ def dev(ctx, host="127.0.0.1", port=8000):
 @task
 def pull_db(ctx):
     """Pull a local copy of the remote DB and reset all passwords"""
+    _local_dotenv_if_not_exists()
+
     with Connection(config.host) as conn:
         e = _srv_env(conn, f"{config.domain}/.env")
 
@@ -263,20 +256,21 @@ def _srv_env(conn, path):
 def mm(ctx, language=None):
     """Update the translation catalogs"""
 
-    with io.open("conf/strings.js", "w", encoding="utf-8") as f:
+    with open("conf/strings.js", "w", encoding="utf-8") as f:
+        f.write("/* eslint-disable */\n")
         f.write("".join(f"{str}\n" for str in generate_strings()))
 
     language = f"-l {language}" if language else "-a"
     run(
         ctx,
         f"venv/bin/python manage.py makemessages {language} --add-location file"
-        " -i venv -i htmlcov -i node_modules -i lib -i build -i dist",
+        " -i venv -i htmlcov -i node_modules -i lib -i build -i dist --no-wrap",
         replace_env=False,
     )
     run(
         ctx,
         f"venv/bin/python manage.py makemessages {language} --add-location file"
-        " -i venv -i htmlcov -i node_modules -i lib -i build -i dist"
+        " -i venv -i htmlcov -i node_modules -i lib -i build -i dist --no-wrap"
         " -d djangojs",
         replace_env=False,
     )
@@ -311,6 +305,7 @@ def upgrade(ctx, stable=False):
     extra = "" if stable else "--pre"
     run(ctx, f"venv/bin/python -m pip install -U -r requirements-to-freeze.txt {extra}")
     freeze(ctx)
+    hook(ctx)
 
 
 @task
@@ -335,6 +330,7 @@ def update(ctx):
     run(ctx, 'find . -name "*.pyc" -delete')
     run(ctx, "yarn")
     run(ctx, "venv/bin/python manage.py migrate", warn=True)
+    hook(ctx)
 
 
 def _local_dotenv_if_not_exists():
@@ -342,7 +338,7 @@ def _local_dotenv_if_not_exists():
     if dotenv.exists():
         return
 
-    secret_key = _random_string(50)
+    secret_key = _random_string(70)
     dbname = _dbname_from_domain(config.domain)
 
     with dotenv.open("w") as f:
@@ -352,7 +348,7 @@ DEBUG=True
 DATABASE_URL=postgres://localhost:5432/{dbname}
 CACHE_URL=hiredis://localhost:6379/1/?key_prefix={dbname}
 SECRET_KEY={secret_key}
-ALLOWED_HOSTS=["*"]
+ALLOWED_HOSTS=["*", ".localhost"]
 
 SENTRY_DSN=
 SENTRY_ENVIRONMENT=
@@ -431,8 +427,7 @@ def nine_alias_remove(ctx, alias, include_www=False):
 def nine_unit(ctx):
     """Start and enable a gunicorn@ unit"""
     with Connection(config.host) as conn:
-        run(conn, f"systemctl --user start gunicorn@{config.domain}.service")
-        run(conn, f"systemctl --user enable gunicorn@{config.domain}.service")
+        run(conn, f"systemctl --user enable --now gunicorn@{config.domain}.service")
 
 
 def _nine_has_manage_databases(conn):
@@ -451,7 +446,7 @@ def nine_db_dotenv(ctx):
             terminate(f"'{config.domain}/.env' already exists on the server")
 
         password = _random_string(20, chars="abcdefghijklmnopqrstuvwxyz0123456789")
-        secret_key = _random_string(50)
+        secret_key = _random_string(70)
         dbname = _dbname_from_domain(config.domain)
 
         if _nine_has_manage_databases(conn):
@@ -496,8 +491,8 @@ SENTRY_DSN=
 SENTRY_ENVIRONMENT=
 
 # LIVE=True
-# CANONICAL_DOMAIN={config.domain}
-# CANONICAL_DOMAIN_SECURE=True
+# SECURE_SSL_HOST={config.domain}
+# SECURE_SSL_REDIRECT=True
 """
             ),
             f"{config.domain}/.env",
@@ -537,8 +532,7 @@ def nine_disable(ctx):
     """Disable a virtual host, dump and remove the DB and stop the gunicorn@ unit"""
     with Connection(config.host) as conn:
         run(conn, f"sudo nine-manage-vhosts virtual-host remove {config.domain}")
-        run(conn, f"systemctl --user stop gunicorn@{config.domain}.service")
-        run(conn, f"systemctl --user disable gunicorn@{config.domain}.service")
+        run(conn, f"systemctl --user disable --now gunicorn@{config.domain}.service")
 
         e = _srv_env(conn, f"{config.domain}/.env")
         srv_dsn = e("DATABASE_URL")
@@ -561,12 +555,15 @@ def nine_checkout(ctx):
         run(conn, f"git clone {repo} {config.domain} -b {config.branch}")
 
 
-@task
-def nine_venv(ctx):
+@task(
+    auto_shortflags=False,
+    help={"python3": "Python executable"},
+)
+def nine_venv(ctx, python3="python3"):
     """Create a venv and install packages from requirements.txt"""
     with Connection(config.host) as conn, conn.cd(config.domain):
         run(conn, "rm -rf venv")
-        run(conn, "PATH=~/.pyenv/shims:$PATH python3 -m venv venv")
+        run(conn, f"PATH=~/.pyenv/shims:$PATH {python3} -m venv venv")
         _pip_up(conn)
         run(conn, "venv/bin/python -m pip install -r requirements.txt")
 
@@ -678,45 +675,6 @@ def fetch(ctx):
     run(ctx, f"git fetch {config.remote}")
 
 
-# legacy
-def _check_flake8(ctx):
-    run(ctx, "pipx run flake8 .")
-
-
-# legacy
-def _check_django(ctx):
-    run(ctx, "venv/bin/python manage.py check")
-
-
-# legacy
-def _check_prettier(ctx):
-    run(
-        ctx,
-        f"yarn run prettier --list-different --no-semi"
-        f' "*.js" "{config.app}/static/**/*.js" "{config.app}/static/**/*.scss"',
-    )
-
-
-# legacy
-def _check_eslint(ctx):
-    run(ctx, f'yarn run eslint "*.js" {config.app}/static')
-
-
-# legacy
-def _check_large_files(ctx, *, limit=500000):
-    out = run(
-        ctx, "git diff-index --cached --name-only --diff-filter=AMT HEAD", hide=True
-    ).stdout.strip()
-    sizes = ((f, os.stat(f).st_size) for f in out.splitlines())
-    large = {f: size for f, size in sizes if size > limit}
-    if large:
-        files = ", ".join(
-            f"{f} ({size // 1000}kb)"
-            for f, size in sorted(large.items(), key=lambda r: r[1])
-        )
-        terminate(f"Large files detected: {files}")
-
-
 def _check_branch(ctx):
     branch = run(ctx, "git rev-parse --abbrev-ref HEAD", hide=True).stdout.strip()
     if branch != config.branch:
@@ -736,51 +694,6 @@ def check(ctx):
     run(ctx, "pre-commit run")
 
 
-def _fmt_prettier(ctx):
-    run(
-        ctx,
-        f"yarn run prettier --write --no-semi"
-        f' "*.js" "{config.app}/static/**/*.js" "{config.app}/static/**/*.scss"',
-        warn=True,
-    )
-
-
-def _fmt_tox_style(ctx):
-    run(ctx, "tox -e style", warn=True)
-
-
-def _fmt_pyupgrade(ctx):
-    run(ctx, "pipx run pyupgrade --py36-plus $(git ls-files '*.py')", warn=True)
-
-
-def _fmt_black(ctx):
-    run(ctx, "pipx run black .", warn=True)
-
-
-def _fmt_isort(ctx):
-    run(
-        ctx,
-        "pipx run isort"
-        " --virtual-env venv --profile=black --lines-after-imports=2 --combine-as"
-        " .",
-        warn=True,
-    )
-
-
-def _fmt_djlint(ctx):
-    run(ctx, f"pipx run djlint --reformat --quiet {config.app}", warn=True)
-
-
-@task
-def fmt(ctx):
-    """Format the code"""
-    _fmt_pyupgrade(ctx)
-    _fmt_black(ctx)
-    _fmt_isort(ctx)
-    # _fmt_djlint(ctx)
-    _fmt_prettier(ctx)
-
-
 def _deploy_django(conn):
     run(conn, "git fetch origin")
     run(conn, f"git checkout {config.branch}")
@@ -816,10 +729,10 @@ def deploy(ctx, fast=False, force=False):
     _check_branch(ctx)
     _check_no_uncommitted_changes(ctx)
     check(ctx)
-    force = "+" if (force or config.force) else ""
+    force = "--force-with-lease " if (force or config.force) else ""
     run(ctx, f"git push origin {force}{config.branch}")
     if not fast:
-        run(ctx, "NODE_ENV=production yarn run webpack -p --bail")
+        run(ctx, "NODE_ENV=production yarn run webpack --mode production --bail")
 
     with Connection(config.host) as conn, conn.cd(config.domain):
         _deploy_django(conn)
@@ -848,7 +761,6 @@ GENERAL = {
     github,
     fetch,
     check,
-    fmt,
     deploy,
 }
 NINE = {
